+++
title = "Project Definition"
description = "Goals, objectives and approach"
date = "2019-08-07"
author = "Christian Decker"
sec = 2
+++

This section defines concisely the basic project frame.

### Goal

Improve my CV by adding new state-of-the-art development skills.

### Approach & Objectives

* To be able to setup a Raspi from scratch
* To be able to develop a simple command line software
* To enable a software to automatically restart after shutdown / power off
* To enable resilience by monitoring and restarting software processes remotely





